@@ -22,9 +22,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#include "sch_drawing_tools.h"
-#include "ee_selection_tool.h"
-#include "ee_grid_helper.h"
+#include <tools/sch_drawing_tools.h>
+#include <tools/ee_selection_tool.h>
+#include <tools/ee_grid_helper.h>
 #include <ee_actions.h>
 #include <sch_edit_frame.h>
 #include <project.h>
@@ -987,6 +987,7 @@ int SCH_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
     SCH_ITEM*             item = nullptr;
     KIGFX::VIEW_CONTROLS* controls = getViewControls();
     EE_GRID_HELPER        grid( m_toolMgr );
+    bool                  ignorePrimePosition = false;
 
     if( m_inTwoClickPlace )
         return 0;
@@ -1048,10 +1049,17 @@ int SCH_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
     setCursor();
 
     // Prime the pump if the tool isn't being re-activated
-    if( aEvent.HasPosition() || ( !aEvent.IsReactivate()
-            && ( isText || isGlobalLabel || isHierLabel || isNetLabel ) ) )
+    if( aEvent.HasPosition() )
     {
-        m_toolMgr->RunAction( ACTIONS::cursorClick );
+        m_toolMgr->PrimeTool( aEvent.Position() );
+    }
+    else if( !aEvent.IsReactivate() && ( isText
+                                         || isGlobalLabel
+                                         || isHierLabel
+                                         || isNetLabel ) )
+    {
+        m_toolMgr->PrimeTool( { 0, 0 } );
+        ignorePrimePosition = true;
     }
 
     // Main loop: keep receiving events
@@ -1170,11 +1178,17 @@ int SCH_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
                     }
                 }
 
-                // Restore cursor after dialog
-                controls->WarpCursor( controls->GetCursorPosition(), true );
+                // If we started with a click on a tool button or menu then continue with the
+                // current mouse position.  Otherwise warp back to the original click position.
+                if( evt->IsPrime() && ignorePrimePosition )
+                    cursorPos = grid.Align( controls->GetMousePosition() );
+                else
+                    controls->WarpCursor( cursorPos, true );
 
                 if( item )
                 {
+                    item->SetPosition( (wxPoint) cursorPos );
+
                     item->SetFlags( IS_NEW | IS_MOVING );
                     item->AutoplaceFields( /* aScreen */ nullptr, /* aManual */ false );
                     updatePreview();
@@ -1438,8 +1452,8 @@ void SCH_DRAWING_TOOLS::sizeSheet( SCH_SHEET* aSheet, const VECTOR2I& aPos )
     wxPoint pos = aSheet->GetPosition();
     wxPoint size = (wxPoint) aPos - pos;
 
-    size.x = std::max( size.x, MIN_SHEET_WIDTH );
-    size.y = std::max( size.y, MIN_SHEET_HEIGHT );
+    size.x = std::max( size.x, Mils2iu( MIN_SHEET_WIDTH ) );
+    size.y = std::max( size.y, Mils2iu( MIN_SHEET_HEIGHT ) );
 
     wxPoint grid = m_frame->GetNearestGridPosition( pos + size );
     aSheet->Resize( wxSize( grid.x - pos.x, grid.y - pos.y ) );
